# Statistical Summary For Neuroscience
A statistical summary commandline tool for OpenEphys binary data, and specifically formatted .mat data.

## How To Use
Run this command, and you should see progress updates in the terminal, and plots will come up after a couple minutes. 
```
python3 location/to/summary/summary_statistics.py location/to/binary_data_or_mat
```


